/**
  ******************************************************************************
  * @file    haplink_encoders.cpp 
  * @author  melisao@stanford.edu
  * @version 1.0
  * @date    October-2017
  * @brief   Controls Haplink's encoders channels for sensor reading.
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "haplink_encoders.h"
#include "stm32f4xx_syscfg_mort.h"

/* Global variables -----------------------------------------------------------*/
bool Ap_s1;
bool Bp_s1;
bool A_s1;
bool B_s1;
bool Ap_s2;
bool Bp_s2;
bool A_s2;
bool B_s2;

int32_t CountsSensor1;
int32_t CountsSensor2;

/* Function Definitions ------------------------------------------------------*/
int32_t getCountsSensor1( void )
{
    return CountsSensor1;    
}
int32_t getCountsSensor2( void )
{
    return CountsSensor2;    
}

void initEncoders( void )
{
    EXTI_InitTypeDef_mort   EXTI_InitStructure;
    GPIO_InitTypeDef_mort   GPIO_InitStructure;
    NVIC_InitTypeDef_mort   NVIC_InitStructure;
    
    /* Init tracking variables*/
    
    
    /* Enable GPIOG clock */
    RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOG, ENABLE);
    
    /* Enable SYSCFG clock */
    RCC_APB2PeriphClockCmd(RCC_APB2Periph_SYSCFG, ENABLE);
    
    /* Configure PG15, 14, 13, 12 pin as input floating */
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN;
    GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_15 | GPIO_Pin_14 | GPIO_Pin_13 | GPIO_Pin_12;
    GPIO_Init_mort(GPIOG_MORT, &GPIO_InitStructure);
    
    Ap_s1 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_15));
    Bp_s1 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_14));
    A_s1 = Ap_s1;
    B_s1 = Bp_s1;
    Ap_s2 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_13));
    Bp_s2 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_12));;
    A_s2 = Ap_s2;
    B_s2 = Bp_s2;
    CountsSensor1 = 0;
    CountsSensor2 = 0;
    
    /* Connect EXTI Line15 to PG15 pin */
    SYSCFG_EXTILineConfig_mort(EXTI_PortSourceGPIOG_MORT, EXTI_PinSource15_MORT);
    /* Connect EXTI Line14 to PG14 pin */
    SYSCFG_EXTILineConfig_mort(EXTI_PortSourceGPIOG_MORT, EXTI_PinSource14_MORT);
    /* Connect EXTI Line13 to PG13 pin */
    SYSCFG_EXTILineConfig_mort(EXTI_PortSourceGPIOG_MORT, EXTI_PinSource13_MORT);
    /* Connect EXTI Line12 to PG12 pin */
    SYSCFG_EXTILineConfig_mort(EXTI_PortSourceGPIOG_MORT, EXTI_PinSource12_MORT);
    
    /* Configure EXTI Line15 */
    EXTI_InitStructure.EXTI_Line = EXTI_Line15_MORT;
    EXTI_InitStructure.EXTI_Mode = EXTI_Mode_Interrupt;
    EXTI_InitStructure.EXTI_Trigger = EXTI_Trigger_Rising_Falling;
    EXTI_InitStructure.EXTI_LineCmd = ENABLE;
    EXTI_Init_mort(&EXTI_InitStructure);
    /* Configure EXTI Line14 */
    EXTI_InitStructure.EXTI_Line = EXTI_Line14_MORT;
    EXTI_InitStructure.EXTI_Mode = EXTI_Mode_Interrupt;
    EXTI_InitStructure.EXTI_Trigger = EXTI_Trigger_Rising_Falling;
    EXTI_InitStructure.EXTI_LineCmd = ENABLE;
    EXTI_Init_mort(&EXTI_InitStructure);
     /* Configure EXTI Line13 */
    EXTI_InitStructure.EXTI_Line = EXTI_Line13_MORT;
    EXTI_InitStructure.EXTI_Mode = EXTI_Mode_Interrupt;
    EXTI_InitStructure.EXTI_Trigger = EXTI_Trigger_Rising_Falling;
    EXTI_InitStructure.EXTI_LineCmd = ENABLE;
    EXTI_Init_mort(&EXTI_InitStructure);
    /* Configure EXTI Line12 */
    EXTI_InitStructure.EXTI_Line = EXTI_Line12_MORT;
    EXTI_InitStructure.EXTI_Mode = EXTI_Mode_Interrupt;
    EXTI_InitStructure.EXTI_Trigger = EXTI_Trigger_Rising_Falling;
    EXTI_InitStructure.EXTI_LineCmd = ENABLE;
    EXTI_Init_mort(&EXTI_InitStructure);
    
    /* Enable and set EXTI15_10 Interrupt to the lowest priority */
    NVIC_InitStructure.NVIC_IRQChannel = EXTI15_10_IRQn;
    NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0x0F;
    NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0x0F;
    NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;

    NVIC_Init_mort(&NVIC_InitStructure);
     
    
}


extern "C" void EXTI15_10_IRQHandler(void)
{
  if(EXTI_GetITStatus_mort(EXTI_Line15_MORT) != RESET) // channel A s1
  {
    A_s1 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_15));
    B_s1 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_14));
    if (((Ap_s1 == Bp_s1)&&(A_s1 == (!B_s1)))||((A_s1==B_s1)&&(Ap_s1==(!Bp_s1))))
    {
        if ((B_s1 == Ap_s1)&&(A_s1==(!Bp_s1)))
        {
            CountsSensor1 = CountsSensor1 + 1; //CL rotation
        }
        else
        {
            CountsSensor1 = CountsSensor1 - 1; //CCL rotation 
        }
    }
    Ap_s1 = A_s1;
    Bp_s1 = B_s1;
    
    /* Clear the EXTI line 15 pending bit */
    EXTI_ClearITPendingBit_mort(EXTI_Line15_MORT);
  }
  else if(EXTI_GetITStatus_mort(EXTI_Line14_MORT) != RESET) // channel B s1
  {
    A_s1 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_15));
    B_s1 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_14));
    if (((Ap_s1 == Bp_s1)&&(A_s1 == (!B_s1)))||((A_s1==B_s1)&&(Ap_s1==(!Bp_s1))))
    {
        if ((B_s1 == Ap_s1)&&(A_s1==(!Bp_s1)))
        {
            CountsSensor1 = CountsSensor1 + 1; //CL rotation
        }
        else
        {
            CountsSensor1 = CountsSensor1 - 1; //CCL rotation 
        }
    }
    Ap_s1 = A_s1;
    Bp_s1 = B_s1;
    /* Clear the EXTI line 14 pending bit */
    EXTI_ClearITPendingBit_mort(EXTI_Line14_MORT);
  }
  else if(EXTI_GetITStatus_mort(EXTI_Line13_MORT) != RESET) // channel A m2
  {
    A_s2 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_13));
    B_s2 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_12));
    if (((Ap_s2 == Bp_s2)&&(A_s2 == (!B_s2)))||((A_s2==B_s2)&&(Ap_s2==(!Bp_s2))))
    {
        if ((B_s2 == Ap_s2)&&(A_s2==(!Bp_s2)))
        {
            CountsSensor2 = CountsSensor2 + 1; //CL rotation
        }
        else
        {
            CountsSensor2 = CountsSensor2 - 1; //CCL rotation 
        }
    }
    Ap_s2 = A_s2;
    Bp_s2 = B_s2;
    
    /* Clear the EXTI line 13 pending bit */
    EXTI_ClearITPendingBit_mort(EXTI_Line13_MORT);
  }
  else if(EXTI_GetITStatus_mort(EXTI_Line12_MORT) != RESET) // channel B m2
  {
    A_s2 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_13));
    B_s2 = (bool)(GPIO_ReadInputDataBit_mort(GPIOG_MORT, GPIO_Pin_12));
    if (((Ap_s2 == Bp_s2)&&(A_s2 == (!B_s2)))||((A_s2==B_s2)&&(Ap_s2==(!Bp_s2))))
    {
        if ((B_s2 == Ap_s2)&&(A_s2==(!Bp_s2)))
        {
            CountsSensor2 = CountsSensor2 + 1; //CL rotation
        }
        else
        {
            CountsSensor2 = CountsSensor2 - 1; //CCL rotation 
        }
    }
    Ap_s2 = A_s2;
    Bp_s2 = B_s2;
    
    /* Clear the EXTI line 12 pending bit */
    EXTI_ClearITPendingBit_mort(EXTI_Line12_MORT);
  }
}
//EOF