/**
  ******************************************************************************
  * @file    haplink_pwm.cpp 
  * @author  melisao@stanford.edu
  * @version 1.0
  * @date    July-2017
  * @brief   Controls the output to the pwm channels connected to Hapkit and 
             Haplink's motors.
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include <math.h>
#include "haplink_pwm.h"
#include "mbed.h"

/* Macro Definitions----------------------------------------------------------*/
DigitalOut pwm11(PG_5);
DigitalOut pwm12(PG_7);
DigitalOut pwm21(PG_8);
DigitalOut pwm22(PG_9);

/* Global Variables-----------------------------------------------------------*/
TIM_TimeBaseInitTypeDef_mort  TIM_TimeBaseStructure;
TIM_OCInitTypeDef_mort  TIM_OCInitStructure;
uint16_t CCR1_Val = 0;//333;
uint16_t CCR2_Val = 0;//249;
uint16_t CCR3_Val = 0;//166;
uint16_t CCR4_Val = 0;//83;
uint16_t PrescalerValue = 0;

double dutyPrint1 = 0;
double dutyPrint2 = 0;

/* Function Definitions-------------------------------------------------------*/
void outputTorqueMotor1(double torque)
{
    double duty;
    if (torque < 0)
    {
        pwm11 = 0;
        pwm12 = 1;
    }
    else
    {
        pwm11 = 1;
        pwm12 = 0;
    }
    //duty = sqrt(abs(torque)/0.0183);
    duty = abs(torque)*43.8;
    dutyPrint1 = duty;
    updateDutyCycle1(duty);
}
void outputTorqueMotor2(double torque)
{
    double duty;
    if (torque < 0)
    {
        pwm21 = 0;
        pwm22 = 1;
    }
    else
    {
        pwm21 = 1;
        pwm22 = 0;
    }
    //duty = sqrt(abs(torque)/0.0183);
    duty = abs(torque)*43.8;
    dutyPrint2 = duty;
    updateDutyCycle2(duty);
}

void pwmGpioConfig(void)
{
  GPIO_InitTypeDef_mort GPIO_InitStructure;

  /* TIM3 clock enable */
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM3, ENABLE);

  /* GPIOC clock enable */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOC, ENABLE);
  
  /* GPIOC Configuration: TIM3 CH1 (PC6), TIM3 CH2 (PC7), TIM3 CH3 (PC8) and TIM3 CH4 (PC9) */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 | GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_100MHz;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP ;
  GPIO_Init_mort(GPIOC_MORT, &GPIO_InitStructure); 

  /* Connect TIM3 pins to AF2 */  
  GPIO_PinAFConfig_mort(GPIOC_MORT, GPIO_PinSource6, GPIO_AF_TIM3);
  GPIO_PinAFConfig_mort(GPIOC_MORT, GPIO_PinSource7, GPIO_AF_TIM3); 
  GPIO_PinAFConfig_mort(GPIOC_MORT, GPIO_PinSource8, GPIO_AF_TIM3);
  GPIO_PinAFConfig_mort(GPIOC_MORT, GPIO_PinSource9, GPIO_AF_TIM3); 
}

void initHaplinkPwm( void )
{
  //setup dir pins:
  pwm11 = 0;
  pwm12 = 0;
  pwm21 = 0;
  pwm22 = 0;
  //setup pwm pins as pwm pins 
  pwmGpioConfig();
  
  PrescalerValue = (uint16_t) ((SystemCoreClock /2) / 21000000) - 1;

  /* Time base configuration */
  TIM_TimeBaseStructure.TIM_Period = PERIOD;
  TIM_TimeBaseStructure.TIM_Prescaler = PrescalerValue;
  TIM_TimeBaseStructure.TIM_ClockDivision = 0;
  TIM_TimeBaseStructure.TIM_CounterMode = TIM_CounterMode_Up_MORT;

  TIM_TimeBaseInit_mort(TIM3_MORT, &TIM_TimeBaseStructure);

  /* PWM1 Mode configuration: Channel1 */
  TIM_OCInitStructure.TIM_OCMode = TIM_OCMode_PWM1_MORT;
  TIM_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable_MORT;
  TIM_OCInitStructure.TIM_Pulse = CCR1_Val;
  TIM_OCInitStructure.TIM_OCPolarity = TIM_OCPolarity_High_MORT;

  TIM_OC1Init_mort(TIM3_MORT, &TIM_OCInitStructure);

  TIM_OC1PreloadConfig_mort(TIM3_MORT, TIM_OCPreload_Enable_MORT);

  /* PWM1 Mode configuration: Channel2 */
  TIM_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable_MORT;
  TIM_OCInitStructure.TIM_Pulse = CCR2_Val;

  TIM_OC2Init_mort(TIM3_MORT, &TIM_OCInitStructure);

  TIM_OC2PreloadConfig_mort(TIM3_MORT, TIM_OCPreload_Enable_MORT);

  /* PWM1 Mode configuration: Channel3 */
  TIM_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable_MORT;
  TIM_OCInitStructure.TIM_Pulse = CCR3_Val;

  TIM_OC3Init_mort(TIM3_MORT, &TIM_OCInitStructure);

  TIM_OC3PreloadConfig_mort(TIM3_MORT, TIM_OCPreload_Enable_MORT);

  /* PWM1 Mode configuration: Channel4 */
  TIM_OCInitStructure.TIM_OutputState = TIM_OutputState_Enable_MORT;
  TIM_OCInitStructure.TIM_Pulse = CCR4_Val;

  TIM_OC4Init_mort(TIM3_MORT, &TIM_OCInitStructure);

  TIM_OC4PreloadConfig_mort(TIM3_MORT, TIM_OCPreload_Enable_MORT);

  TIM_ARRPreloadConfig_mort(TIM3_MORT, ENABLE);

  /* TIM3 enable counter */
  TIM_Cmd_mort(TIM3_MORT, ENABLE);  
}
/**************************************
 newDuty should be a value betwen 0 and 1
***************************************/
void updateDutyCycle1( double newDuty )
{
    uint32_t newValue;
    if (newDuty > 1)
    {
        newDuty = 1;
    }
    else if (newDuty < 0 )
    {
        newDuty = 0;
    }
    newValue = (uint32_t)(newDuty*PERIOD);
    TIM_SetCompare1_mort(TIM3_MORT, newValue);  
}
/**************************************
 newDuty should be a value betwen 0 and 1
***************************************/
void updateDutyCycle2( double newDuty )
{
    uint32_t newValue;
    if (newDuty > 1)
    {
        newDuty = 1;
    }
    else if (newDuty < 0 )
    {
        newDuty = 0;
    }
    newValue = (uint32_t)(newDuty*PERIOD);
    TIM_SetCompare2_mort(TIM3_MORT, newValue);  
}
/**************************************
 newDuty should be a value betwen 0 and 1
***************************************/
void updateDutyCycle3( double newDuty )
{
    uint32_t newValue;
    if (newDuty > 1)
    {
        newDuty = 1;
    }
    else if (newDuty < 0 )
    {
        newDuty = 0;
    }
    newValue = (uint32_t)(newDuty*PERIOD);
    TIM_SetCompare3_mort(TIM3_MORT, newValue);  
}
/**************************************
 newDuty should be a value betwen 0 and 1
***************************************/
void updateDutyCycle4( double newDuty )
{
    uint32_t newValue;
    if (newDuty > 1)
    {
        newDuty = 1;
    }
    else if (newDuty < 0 )
    {
        newDuty = 0;
    }
    newValue = (uint32_t)(newDuty*PERIOD);
    TIM_SetCompare4_mort(TIM3_MORT, newValue);  
}
//EOF

