/*************************************************
Haplink main: This program supports both
Haplink and Hapkit devices. Use main.h to 
define which device you are using.
**************************************************/
#include "mbed.h"
#include <math.h>
#ifdef MAGNETORESISTIVE
    #include "haplink_adc.h"
#endif
#ifdef ENCODERS
    #include "haplink_encoders.h"
#endif
#include "haplink_position.h"
#include "haplink_pwm.h"

#include "stm32f4xx_tim_mort.h"
#include "USBSerial.h"
#include "main.h"
#include "haplink_virtual_environments.h"

//usb port to send information:
USBSerial serial;
Ticker sensorticker;



//variables needed declared in other files:
extern double J00, J01, J10, J11; //jacobian variables
extern double rx, ry, dx, dy; //position variables
extern double xH, dxH; //Hapkit position variables
extern double dutyPrint1, dutyPrint2; //duty cycle commanded to motors

//variables:
extern double TorqueX, TorqueY, ForceX, ForceY, TorqueMotor1, TorqueMotor2;

int main() {
    //double meas1,meas2;
    int counter = 0;
    initHaplinkPwm();
    initHaplinkPosition();
    #ifdef MAGNETORESISTIVE
        //every 500 us, update the sensor, make sure we don't miss counts
        sensorticker.attach(&updatePosition, 0.0005);
    #endif
    
    while(1) 
    {
         
         #ifdef HAPKIT //you are using Hapkit
            calculatePositionHapkit(); 
            /*Insert here the virtual environment from the file haplink_virtual_environments.cpp
            that you wish to render*/
            blinkLED();
            
         #else //then you are using HAPLINK
            calculatePositionHandleAndJacobian();
            /*Insert here the virtual environment from the file haplink_virtual_environments.cpp
            that you wish to render*/
         #endif
        
         
         //insert prints for debugging here:
         if (counter > 4000) //prints shouldn't happen very frequently
         {
            serial.printf("hello world\n");
            counter = 0;  
         }
         else
         {
             counter++;
         }
  
    }
}

